diff -Nrup /usr/lib/python3/dist-packages/provisioningserver/drivers/power/__init__.py provisioningserver/drivers/power/__init__.py
--- /usr/lib/python3/dist-packages/provisioningserver/drivers/power/__init__.py	2016-12-21 12:56:19.000000000 +0000
+++ provisioningserver/drivers/power/__init__.py	2017-04-02 19:01:59.041822721 +0000
@@ -353,6 +353,7 @@ from provisioningserver.drivers.power.uc
 from provisioningserver.drivers.power.virsh import VirshPowerDriver
 from provisioningserver.drivers.power.vmware import VMwarePowerDriver
 from provisioningserver.drivers.power.nova import NovaPowerDriver
+from provisioningserver.drivers.power.wakeonlan import WakeOnLANPowerDriver
 
 power_drivers = [
     AMTPowerDriver(),
@@ -371,6 +372,7 @@ power_drivers = [
     VirshPowerDriver(),
     VMwarePowerDriver(),
     NovaPowerDriver(),
+    WakeOnLANPowerDriver(),
 ]
 for driver in power_drivers:
     PowerDriverRegistry.register_item(driver.name, driver)
diff -Nrup /usr/lib/python3/dist-packages/provisioningserver/drivers/power/wakeonlan.py provisioningserver/drivers/power/wakeonlan.py
--- /usr/lib/python3/dist-packages/provisioningserver/drivers/power/wakeonlan.py	1970-01-01 00:00:00.000000000 +0000
+++ provisioningserver/drivers/power/wakeonlan.py	2017-04-02 19:01:59.041822721 +0000
@@ -0,0 +1,58 @@
+# Copyright 2016 Canonical Ltd.  This software is licensed under the
+# GNU Affero General Public License version 3 (see the file LICENSE).
+
+"""Wake on LAN Power Driver."""
+
+__all__ = []
+
+from provisioningserver.drivers.power import PowerDriver
+from provisioningserver.logger import get_maas_logger
+from provisioningserver.utils import shell
+from twisted.internet.defer import maybeDeferred
+import subprocess
+
+
+maaslog = get_maas_logger("drivers.power.wakeonlan")
+
+REQUIRED_PACKAGES = [["wakeonlan", "wakeonlan"]]
+
+class WakeOnLANPowerDriver(PowerDriver):
+
+    name = 'wakeonlan'
+    description = "Wake on LAN Power Driver."
+    settings = []
+
+    def detect_missing_packages(self):
+        missing_packages = set()
+        for binary, package in REQUIRED_PACKAGES:
+            if not shell.has_command_available(binary):
+                missing_packages.add(package)
+        return list(missing_packages)
+
+    def on(self, system_id, context):
+        """Override `on` as we do not need retry logic."""
+        return maybeDeferred(self.power_on, system_id, context)
+
+    def off(self, system_id, context):
+        """Override `off` as we do not need retry logic."""
+        return maybeDeferred(self.power_off, system_id, context)
+
+    def query(self, system_id, context):
+        """Override `query` as we do not need retry logic."""
+        return maybeDeferred(self.power_query, system_id, context)
+
+    def power_on(self, system_id, context):
+        """Power on machine using wake on lan."""
+        subprocess.call(["wakeonlan", context.get("power_mac")])
+
+
+    def power_off(self, system_id, context):
+        """Power off machine manually."""
+        maaslog.info(
+            "You need to power off %s manually." % system_id)
+
+    def power_query(self, system_id, context):
+        """Power query machine manually."""
+        maaslog.info(
+            "You need to check power state of %s manually." % system_id)
+        return 'unknown'
diff -Nrup /usr/lib/python3/dist-packages/provisioningserver/power/schema.py provisioningserver/power/schema.py
--- /usr/lib/python3/dist-packages/provisioningserver/power/schema.py	2016-12-21 12:56:19.000000000 +0000
+++ provisioningserver/power/schema.py	2017-04-02 19:01:59.001823063 +0000
@@ -235,6 +235,13 @@ JSON_POWER_TYPE_PARAMETERS = [
         'fields': [],
     },
     {
+        'name': 'wakeonlan',
+        'description': 'Wake on LAN',
+        'fields': [
+            make_json_field('power_mac', "MAC address", required=True),
+        ],
+    },
+    {
         'name': 'virsh',
         'description': 'Virsh (virtual systems)',
         'fields': [
